@@ -379,7 +379,7 @@ private Q_SLOTS:
             QFINDTESTDATA(QStringLiteral("fixtures/overrides.in/com.example.cascade.user-app")),
         };
         FlatpakPermissionModel model;
-        FlatpakReference reference("com.example.cascade.metadata", "x86_64", "stable", "1.0.0", "com.example.cascade.metadata", overrideFiles);
+        FlatpakReference reference("com.example.cascade.metadata", "x86_64", "stable", "com.example.cascade.metadata", overrideFiles);
         model.setReference(&reference);
         model.setShowAdvanced(true);
         model.load();
@@ -432,7 +432,7 @@ private Q_SLOTS:
     {
         // The primary motivation behind this test is to make sure that translations aren't being pulled in for the raw names.
         FlatpakPermissionModel model;
-        FlatpakReference reference("com.discordapp.Discord", "x86_64", "stable", "0.0.24", "Discord", mockMetadataAndOverridesFiles("com.discordapp.Discord"));
+        FlatpakReference reference("com.discordapp.Discord", "x86_64", "stable", "Discord", mockMetadataAndOverridesFiles("com.discordapp.Discord"));
         model.setReference(&reference);
         model.load();
         bool containsNetwork = false;
@@ -466,7 +466,6 @@ private Q_SLOTS:
         FlatpakReference reference("com.example.same.override",
                                    "x86_64",
                                    "stable",
-                                   "0.0.24",
                                    "Test Same Simple Override",
                                    mockMetadataAndOverridesFiles("com.example.same.override"));
         model.setReference(&reference);
@@ -517,7 +516,7 @@ private Q_SLOTS:
         // the well-known "host-etc" filesystem would not be the last one. But we want to test for the last
         // default index too.
         FlatpakPermissionModel model;
-        FlatpakReference reference("org.gnome.dfeet", "x86_64", "stable", "0.3.16", "D-Feet", mockMetadataAndOverridesFiles("org.gnome.dfeet"));
+        FlatpakReference reference("org.gnome.dfeet", "x86_64", "stable", "D-Feet", mockMetadataAndOverridesFiles("org.gnome.dfeet"));
         model.setReference(&reference);
         model.load();
         QStringList filesystems;
@@ -548,7 +547,7 @@ private Q_SLOTS:
         // from, and saved.
         const auto metadataAndOverridesFiles = mockMetadataAndOverridesFiles("org.gnome.dfeet");
         FlatpakPermissionModel model;
-        FlatpakReference reference("org.gnome.dfeet", "x86_64", "stable", "0.3.16", "D-Feet", metadataAndOverridesFiles);
+        FlatpakReference reference("org.gnome.dfeet", "x86_64", "stable", "D-Feet", metadataAndOverridesFiles);
         model.setReference(&reference);
         model.load();
         model.setShowAdvanced(true);
@@ -658,7 +657,7 @@ private Q_SLOTS:
     void testDBusBrokenPolicies()
     {
         FlatpakPermissionModel model;
-        FlatpakReference reference("org.gnome.Boxes", "x86_64", "stable", "43.1", "Boxes", mockMetadataAndOverridesFiles("org.gnome.Boxes"));
+        FlatpakReference reference("org.gnome.Boxes", "x86_64", "stable", "Boxes", mockMetadataAndOverridesFiles("org.gnome.Boxes"));
         model.setReference(&reference);
         model.load();
         model.setShowAdvanced(true);
@@ -714,7 +713,7 @@ private Q_SLOTS:
         // Ensure override files mutate properly
         const auto metadataAndOverridesFiles = mockMetadataAndOverridesFiles("com.discordapp.Discord");
         FlatpakPermissionModel model;
-        FlatpakReference reference("com.discordapp.Discord", "x86_64", "stable", "0.0.24", "Discord", metadataAndOverridesFiles);
+        FlatpakReference reference("com.discordapp.Discord", "x86_64", "stable", "Discord", metadataAndOverridesFiles);
         model.setReference(&reference);
         model.load();
         model.setShowAdvanced(true);
@@ -843,7 +842,7 @@ private Q_SLOTS:
     {
         const auto metadataAndOverridesFiles = mockMetadataAndOverridesFiles("com.example.unparsable.filesystems");
         FlatpakPermissionModel model;
-        FlatpakReference reference("com.example.unparsable.filesystems", "x86_64", "stable", "0.0.24", "Unparsable Filesystems", metadataAndOverridesFiles);
+        FlatpakReference reference("com.example.unparsable.filesystems", "x86_64", "stable", "Unparsable Filesystems", metadataAndOverridesFiles);
         model.setReference(&reference);
         model.load();
         model.setShowAdvanced(true);
@@ -864,7 +863,6 @@ private Q_SLOTS:
         FlatpakReference reference("com.example.home.filesystems",
                                    "x86_64",
                                    "stable",
-                                   "0.0.24",
                                    "Default Home Filesystems",
                                    mockMetadataAndOverridesFiles("com.example.home.filesystems"));
         FlatpakPermissionModel model;
@@ -898,12 +896,7 @@ private Q_SLOTS:
     void testValidNames()
     {
         FlatpakPermissionModel model;
-        FlatpakReference reference("com.example.valid.names",
-                                   "x86_64",
-                                   "stable",
-                                   "1.0",
-                                   "Valid Names",
-                                   mockMetadataAndOverridesFiles("com.example.valid.names"));
+        FlatpakReference reference("com.example.valid.names", "x86_64", "stable", "Valid Names", mockMetadataAndOverridesFiles("com.example.valid.names"));
         model.setReference(&reference);
         model.load();
         model.setShowAdvanced(true);
